package GGI::Coord;

=head1 NAME

Coord  -  Perl interface to the LibGGI ggi_color type

=head1 SYNOPSIS

  use GGI::Coord;
  $point = new GGI::Coord;

  $x = $point->x;
  $point->x(0);
  $y = $point->y;
  $point->y(0);

=head1 DESCRIPTION

Implements a simple set of methods which access the internals of LibGGI's 
ggi_coord structure.

=cut

    1;
use strict;
use Carp;
use vars qw($VERSION @ISA @EXPORT @EXPORT_OK $AUTOLOAD);

require DynaLoader;
require AutoLoader;

@ISA = qw(DynaLoader);

$VERSION = '0.01';

sub new {
    my ($class) = shift();
    my $this = {};
    $this->{did_malloc} = 1;
    $this->{obj} = ggi_coord_malloc();
    bless $this, $class;
    return $this;
}

sub not_quite_new {
    my ($class) = shift();
    my $this = {};
    $this->{obj} = shift();
    bless $this, $class;
    return $this;
}

sub x {
    my $this = shift();
    if (@_ + 0) {
	return ggi_coord_set_member_x($this->{obj}, shift());
    }
    return ggi_coord_get_member_x($this->{obj});
}

sub y {
    my $this = shift();
    if (@_ + 0) {
	return ggi_coord_set_member_y($this->{obj}, shift());
    }
    return ggi_coord_get_member_y($this->{obj});
}

sub DESTROY {
    my $this = shift();
    if ($this->{did_malloc}) {
	ggi_coord_free($this->{obj});
    }
    $this->{obj} = undef();
}

sub AUTOLOAD {
    $AutoLoader::AUTOLOAD = $AUTOLOAD;
    goto &AutoLoader::AUTOLOAD;
}

bootstrap GGI::Coord $VERSION;

# Preloaded methods

1;
__END__

=head1 AUTHOR

Brian S. Julin <bri@calyx.com>

=head1 SEE ALSO

GGI::(3pm), perl(1).

=cut
